@@ -7,11 +7,11 @@ CGI::Application::Plugin::AnyTemplate - Use any templating system from within CG
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -60,17 +60,17 @@ the fly.
 This approach has many uses.  For instance, it can be useful in
 migrating your application from one templating system to another.
 
-=head2 Component Dispatch
+=head2 Embedded Components
 
 In addition to template abstraction, C<AnyTemplate> also provides a
-I<component dispatch mechanism>.  For instance, you might include a
+I<embedded component mechanism>.  For instance, you might include a
 I<header> component at the top of every page and a I<footer> component
 at the bottom of every page.
 
 These components are actually full L<CGI::Application> run modes, and
 can do anything normal run mode can do, including processing form
 parameters and filling in their own templates.  See
-below under L<"COMPONENT DISPATCH"> for details.
+below under L<"EMBEDDED COMPONENTS"> for details.
 
 =head2 Multiple Named Template Configurations
 
@@ -289,15 +289,15 @@ it, pass a value of zero:
         auto_add_template_extension => 0,
     );
 
-=item dispatcher_class
+=item component_handler_class
 
-Normally, component dispatching is handled by
-L<CGI::Application::Plugin::AnyTemplate::Dispatcher>.  If you want to
+Normally, component embedding is handled by
+L<CGI::Application::Plugin::AnyTemplate::ComponentHandler>.  If you want to
 use a different class for this purpose, specify the class name as the
 value of this paramter.
 
 It still has to provide the same interface as
-L<CGI::Application::Plugin::AnyTemplate::Dispatcher>.  See the source
+L<CGI::Application::Plugin::AnyTemplate::ComponentHandler>.  See the source
 code of that module for details.
 
 =back
@@ -571,13 +571,13 @@ sub load {
     # create and initialize driver
 
     my $driver = $driver_class->_new(
-         'driver_config'    => \%driver_config,
-         'native_config'    => $native_config,
-         'include_paths'    => $include_paths,
-         'filename'         => $filename,
-         'callers_package'  => $plugin_config->{'callers_package'},
-         'webapp'           => $self->{'webapp'},
-         'dispatcher_class' => $plugin_config->{'dispatcher_class'},
+         'driver_config'           => \%driver_config,
+         'native_config'           => $native_config,
+         'include_paths'           => $include_paths,
+         'filename'                => $filename,
+         'callers_package'         => $plugin_config->{'callers_package'},
+         'webapp'                  => $self->{'webapp'},
+         'component_handler_class' => $plugin_config->{'component_handler_class'},
     );
 
     return $driver;
@@ -594,7 +594,7 @@ sub _plugin_config_keys {
         include_paths
         add_include_paths
         file
-        dispatcher_class
+        component_handler_class
     /;
 }
 
@@ -910,10 +910,10 @@ to the output generated by the template.  You can modify this output:
 
 
 When you call the C<output> method, any components embedded in the
-template are run.  See L<"COMPONENT DISPATCH">, below.
+template are run.  See L<"EMBEDDED COMPONENTS">, below.
 
 
-=head1 COMPONENT DISPATCH
+=head1 EMBEDDED COMPONENTS
 
 =head2 Introduction
 
@@ -932,26 +932,26 @@ template and return the template's output.
 This output returned from the embedded run mode is inserted into the
 containing template.
 
-The syntax for dispatching to embedded components is specific to each
-type of template driver.
+The syntax for embed components is specific to each type of template
+driver.
 
 =head2 Syntax
 
 L<HTML::Template> syntax:
 
-    <TMPL_VAR NAME="CGIAPP_dispatch('some_run_mode')">
+    <TMPL_VAR NAME="CGIAPP_embed('some_run_mode')">
 
 L<HTML::Template::Expr> syntax:
 
-    <TMPL_VAR EXPR="CGIAPP_dispatch('some_run_mode')">
+    <TMPL_VAR EXPR="CGIAPP_embed('some_run_mode')">
 
 L<Template::Toolkit|Template> syntax:
 
-    [% CGIAPP.dispatch("some_run_mode") %]
+    [% CGIAPP.embed("some_run_mode") %]
 
 L<Petal> syntax:
 
-    <span tal:replace="structure CGIAPP/dispatch 'some_run_mode'">
+    <span tal:replace="structure CGIAPP/embed 'some_run_mode'">
         this text gets replaced by the output of some_run_mode
     </span>
 
@@ -993,7 +993,7 @@ barewords.
 
 L<HTML::Template> syntax:
 
-    <TMPL_VAR NAME="CGIAPP_dispatch('some_run_mode', param1, 'literal string2')">
+    <TMPL_VAR NAME="CGIAPP_embed('some_run_mode', param1, 'literal string2')">
 
 I<Note that HTML::Template doesn't support this type of callback natively>
 I<and that this behaviour is emulated by the HTMLTemplate driver>
@@ -1002,15 +1002,15 @@ I<for limitations to the emulation>.
 
 L<HTML::Template::Expr> syntax:
 
-    <TMPL_VAR EXPR="CGIAPP_dispatch('some_run_mode', param1, 'literal string2')">
+    <TMPL_VAR EXPR="CGIAPP_embed('some_run_mode', param1, 'literal string2')">
 
 L<Template::Toolkit|Template> syntax:
 
-    [% CGIAPP.dispatch("some_run_mode", param1, 'literal string2' ) %]
+    [% CGIAPP.embed("some_run_mode", param1, 'literal string2' ) %]
 
 L<Petal> syntax:
 
-    <span tal:replace="structure CGIAPP/dispatch 'some_run_mode' param1 'literal string2' ">
+    <span tal:replace="structure CGIAPP/embed 'some_run_mode' param1 'literal string2' ">
         this text gets replaced by the output of some_run_mode
     </span>
 
@@ -1097,7 +1097,7 @@ be notified of progress on your bug as I make changes.
 =head1 SEE ALSO
 
     CGI::Application::Plugin::AnyTemplate::Base
-    CGI::Application::Plugin::AnyTemplate::Dispatcher
+    CGI::Application::Plugin::AnyTemplate::ComponentHandler
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
     CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
