@@ -32,8 +32,8 @@ sub _new {
     $self->{'callers_package'}  = delete $args{'callers_package'};
     $self->{'webapp'}           = delete $args{'webapp'};
 
-    $self->{'dispatcher_class'} = delete $args{'dispatcher_class'}
-                                || 'CGI::Application::Plugin::AnyTemplate::Dispatcher';
+    $self->{'component_handler_class'} = delete $args{'component_handler_class'}
+                                || 'CGI::Application::Plugin::AnyTemplate::ComponentHandler';
 
     bless $self, $class;
 
@@ -181,7 +181,7 @@ to the output generated by the template.  You can modify this output:
 
 
 When you call the C<output> method, any components embedded in the
-template are run.  See C<COMPONENT DISPATCH>, below.
+template are run.  See C<EMBEDDED COMPONENTS>, below.
 
 =cut
 
@@ -286,28 +286,28 @@ For instance, the user can specify
 
     $self->template->config(
         HTMLTemplate => {
-              dispatch_tag_name     => 'dispatch',
-              global_vars           => 1,
-              die_on_bad_params     => 0,
-              cache                 => 1
+              embed_tag_name    => 'embed',
+              global_vars       => 1,
+              die_on_bad_params => 0,
+              cache             => 1
         },
     );
 
 The parameters C<global_vars>, C<die_on_bad_params>, and C<cache> are all
 specific to L<HTML::Template>.  These are considered I<native> parameters.
 
-But C<dispatch_tag_name> configures the
+But C<embed_tag_name> configures the
 C<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate> subclass.  This
 is considered a I<driver> parameter.
 
-Therefore C<'dispatch_tag_name'> should be included in the list of
+Therefore C<'embed_tag_name'> should be included in the list of
 params returned by C<driver_config_params>.
 
 Example C<driver_config_params>:
 
     sub driver_config_keys {
         'template_extension',
-        'dispatch_tag_name'
+        'embed_tag_name'
     }
 
 =cut
@@ -325,7 +325,7 @@ For instance:
     sub default_driver_config {
         {
             template_extension => '.foo',
-            dispatch_tag_name  => 'dispatch',
+            embed_tag_name     => 'embed',
         };
     }
 
@@ -343,7 +343,7 @@ of filling the template in C<< $self->filename >> with the values in C<< $self->
 via the appropriate template system, and returning the output as either
 a string or a reference to a string.
 
-It also must manage dispatch to nested components.
+It also must manage embedding nested components.
 
 =back
 
@@ -389,7 +389,7 @@ be notified of progress on your bug as I make changes.
 =head1 SEE ALSO
 
     CGI::Application::Plugin::AnyTemplate
-    CGI::Application::Plugin::AnyTemplate::Dispatcher
+    CGI::Application::Plugin::AnyTemplate::ComponentHandler
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
     CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
