@@ -15,25 +15,25 @@ All C<AnyTemplate> drivers are designed to be used the same way.  For
 general usage instructions, see the documentation of
 L<CGI::Application::Plugin::AnyTemplate>.
 
-=head1 COMPONENT DISPATCH SYNTAX (HTML::Template)
+=head1 EMBEDDED COMPONENT SYNTAX (HTML::Template)
 
 =head2 Syntax
 
-The L<HTML::Template> syntax for component dispatch is:
+The L<HTML::Template> syntax for embedding components is:
 
-    <TMPL_VAR NAME="cgiapp_dispatch('some_run_mode', param1, param2, 'literal string3')">
+    <TMPL_VAR NAME="cgiapp_embed('some_run_mode', param1, param2, 'literal string3')">
 
 I<(Support for parameter passing is limited.  See the note on paramters below.)>
 
 This can be overridden by the following configuration variables:
 
-    dispatch_tag_name       # default 'cgiapp_dispatch'
+    embed_tag_name       # default 'cgiapp_embed'
 
 For instance by setting the following value in your configuration file:
 
-    dispatch_tag_name       '***component***'
+    embed_tag_name       '***component***'
 
-Then the component dispatch tag will look like:
+Then the embedded component tag will look like:
 
     <TMPL_VAR NAME="***component***('some_run_mode')">
 
@@ -42,7 +42,7 @@ Then the component dispatch tag will look like:
 Since L<HTML::Template> doesn't support parameter passing in the
 template, the C<HTMLTemplate> driver emulates this behaviour.
 
-The parameter list passed to the dispatch subroutine is parsed before
+The parameter list passed to the embed subroutine is parsed before
 the template is parsed.  Literal strings (strings enclosed in single or
 double quotes) are passed verbatim to the target run mode.  Params not
 enclosed in quotes are looked up in C<< $self->param >>; the resulting
@@ -66,7 +66,7 @@ driver instead.
 use strict;
 use Carp;
 
-use CGI::Application::Plugin::AnyTemplate::Dispatcher;
+use CGI::Application::Plugin::AnyTemplate::ComponentHandler;
 
 use base 'CGI::Application::Plugin::AnyTemplate::Base';
 
@@ -77,10 +77,10 @@ accepts the following config parameters:
 
 =over 4
 
-=item dispatch_tag_name
+=item embed_tag_name
 
-The name of the tag used for component dispatch.  Defaults to
-C<cgiapp_dispatch>.
+The name of the tag used for embedding components.  Defaults to
+C<cgiapp_embed>.
 
 =item template_extension
 
@@ -113,7 +113,7 @@ All other configuration parameters are passed on unchanged to L<HTML::Template>.
 
 sub driver_config_keys {
     qw/
-       dispatch_tag_name
+       embed_tag_name
        template_extension
        associate_query
     /;
@@ -122,7 +122,7 @@ sub driver_config_keys {
 sub default_driver_config {
     (
         template_extension => '.html',
-        dispatch_tag_name  => 'CGIAPP_dispatch',
+        embed_tag_name     => 'CGIAPP_embed',
         associate_query    => 1,
     );
 }
@@ -186,8 +186,8 @@ sub initialize {
 =item render_template
 
 Fills the C<HTML::Template> object with C<< $self->param >>
-replacing any magic C<*dispatch*> tags with the content
-generated by the appropriate runmodes.
+replacing any magic C<*embed*> tags with the content generated by the
+appropriate runmodes.
 
 Returns the output of the filled template as a string reference.
 
@@ -207,7 +207,7 @@ sub render_template {
 
     my $tag_match = '^'
                   . quotemeta(
-                       $driver_config->{'dispatch_tag_name'}
+                       $driver_config->{'embed_tag_name'}
                     )
                   . '\s*'
                   . '\((.*?)\)?'   # optional params
@@ -216,7 +216,7 @@ sub render_template {
 
     $tag_match    = qr/$tag_match/i;
 
-    my $dispatcher = $self->{'dispatcher_class'}->new(
+    my $component_handler = $self->{'component_handler_class'}->new(
         'webapp'              => $self->{'webapp'},
         'containing_template' => $self,
     );
@@ -224,7 +224,7 @@ sub render_template {
     # fill the template
     my $template = $self->{'driver'};
 
-    # fill the CGIAPP_dispatch(foo,...) tags
+    # fill the CGIAPP_embed(foo,...) tags
     foreach my $tag ($template->query) {
         # print STDERR "tag: $tag ($tag_match)\n";
         if ($tag =~ $tag_match) {
@@ -250,7 +250,7 @@ sub render_template {
             my $run_mode = shift @prepped_params;
             # print STDERR "rm: $run_mode (@prepped_params)\n";
 
-            $self->param($tag => ${ $dispatcher->dispatch_direct($run_mode, @prepped_params) });
+            $self->param($tag => ${ $component_handler->embed_direct($run_mode, @prepped_params) });
         }
     }
 
@@ -263,7 +263,7 @@ sub render_template {
 
     CGI::Application::Plugin::AnyTemplate
     CGI::Application::Plugin::AnyTemplate::Base
-    CGI::Application::Plugin::AnyTemplate::Dispatcher
+    CGI::Application::Plugin::AnyTemplate::ComponentHandler
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
     CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
     CGI::Application::Plugin::AnyTemplate::Driver::Petal
